pytilities.descriptors.restricteddescriptor — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.restricteddescriptor

`pytilities.descriptors.restricteddescriptor.` `RestrictedDescriptor`

  A wrapper that hides a combination of set/get/del of a descriptor.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »